@@ -54,11 +54,6 @@
 #include "ulib_opsc.h"
 #endif
 
-// 1.5.0.0 (ge) | chunreal
-#ifndef __DISABLE_REGEX__
-#include "ulib_regex.h"
-#endif
-
 #if defined(__PLATFORM_WIN32__)
   #include "dirent_win32.h"
 #else
@@ -706,11 +701,6 @@ t_CKBOOL load_internal_modules( Chuck_Compiler * compiler )
     if( !load_module( compiler, env, opensoundcontrol_query, "opsc", "global" ) ) goto error;
     #endif
 
-    #ifndef __DISABLE_REGEX__
-    EM_log( CK_LOG_SEVERE, "module 'RegEx'" );
-    if( !load_module( compiler, env, regex_query, "RegEx", "global" ) ) goto error;
-    #endif
-
     // deprecated:
     // if( !load_module( compiler, env, net_query, "net", "global" ) ) goto error;
 
@@ -911,6 +901,21 @@ t_CKBOOL load_external_modules_in_directory( Chuck_Compiler * compiler,
                                                        extension);
                 }
             }
+#ifdef __PLATFORM_MACOSX__
+            // #if __APPLE__ probably cleaner but using the above for consistency for now (ge)
+            // ---
+            // On macOS, a chugin can either be a regular file (a .dylib simply renamed to .chug)
+            // or it can be a MODULE like using CMake with add_library(FooChugin MODULE foo.cpp)
+            // If it's a module bundle, then because .chug is a nonstandard extension,
+            // on the filesystem it shows up as a directory ending in .chug.
+            // If we see one of these directories, we can dive directly to the Contents/MacOS subfolder
+            // and look for a regular file. | 1.5.0.1 (dbraun) added
+            else if (is_directory && extension_matches(de->d_name, extension)) {
+                std::string absolute_path = std::string(directory) + "/" + de->d_name + "/Contents/MacOS";
+                const char* subdirectory = absolute_path.c_str();
+                load_external_modules_in_directory(compiler, subdirectory, "");
+            }
+#endif // #ifdef __PLATFORM_MACOSX__
 
             // read next | 1.5.0.0 (ge) moved here due to #chunreal
             de = readdir( dir );
