@@ -87,8 +87,8 @@ SAMPLE * ChuckAudio::m_buffer_out = NULL;
 SAMPLE * ChuckAudio::m_buffer_in = NULL;
 SAMPLE * ChuckAudio::m_extern_in = NULL;
 SAMPLE * ChuckAudio::m_extern_out = NULL;
-t_CKUINT ChuckAudio::m_dac_n = 0;
-t_CKUINT ChuckAudio::m_adc_n = 0;
+t_CKINT ChuckAudio::m_dac_n = 0;
+t_CKINT ChuckAudio::m_adc_n = 0;
 std::string ChuckAudio::m_dac_name = "";
 std::string ChuckAudio::m_adc_name = "";
 RtAudio * ChuckAudio::m_rtaudio = NULL;
